

##intensity measurer.praat
##James Anderson-Furgeson

#create list of filenames
clearinfo

form Parameters
    comment Directory that contains the original stimuli
    sentence inDirectory /Users/jamesanderson-furgeson/tellerstar/praat_3
    sentence OutDirectory /Users/jamesanderson-furgeson/tellerstar/praat_3/out
    sentence filetype wav
endform

fileList = Create Strings as file list: "list", inDirectory$ + "/*.wav"

#loop for all files
nFiles = Get number of strings
for d to nFiles

	#read in sound file (wav) 
	selectObject: fileList
	fileName$ = Get string... d
	Read from file: inDirectory$ + "/" + fileName$

	# select name of file without '.wav', assign to fileNameNoExt (find the index of the dot in the soundfilename)...
	dotInd = rindex(fileName$, ".")
	fileNameNoExt$ = left$(fileName$, dotInd - 1)

	#find the corresponding textgrid, and read that textgrid from file
	Read from file: inDirectory$ + "/" + fileNameNoExt$ + ".TextGrid"

	#measure overall max intensity, store in maxIntensity
	select TextGrid 'fileNameNoExt$'
	numberOfIntervals = Get number of intervals: 1
	onset = Get starting point... 1 1
	offset = Get end point... 1 numberOfIntervals
	select Sound 'fileNameNoExt$'
	To Intensity... 100 0
	select Intensity 'fileNameNoExt$'
	maxIntensity = Get maximum... onset offset parabolic

	# get pitch
	select Sound 'fileNameNoExt$'
	pitch = To Pitch: 0.01, 75, 600

	select Sound 'fileNameNoExt$'
	manipulation = To Manipulation: 0.01, 75, 600
	select Manipulation 'fileNameNoExt$'
	
	# prepare output file
	outfilename$ = inDirectory$ + "/" + fileNameNoExt$ + ".txt"
	appendFileLine: outfilename$, "start (s)", tab$, "stop (s)", tab$, "volume (MIDI)", tab$, "pitch (Hz)"

	#iterate over intervals in syllables tier (tier 1)
	for i to numberOfIntervals
		select TextGrid 'fileNameNoExt$'
		startTime = Get starting point: 1, i
		endTime = Get end point: 1, i
		
		# select intensity, find mean intensity
		select Intensity 'fileNameNoExt$'
		meanIntensity = Get mean... startTime endTime dB
		volume = 127 * (meanIntensity/maxIntensity)

		# select pitch, find mean pitch
		select Pitch 'fileNameNoExt$'
		meanPitch = Get mean... startTime endTime Hertz

		# might have to remove pitch here
		appendFileLine: outfilename$, startTime, tab$, endTime, tab$, volume, tab$, meanPitch
	endfor

	#Remove objects from object menu
	Remove
	select TextGrid 'fileNameNoExt$'
	Remove
	select Sound 'fileNameNoExt$'
	Remove
	select Intensity 'fileNameNoExt$'
	Remove
	select Manipulation 'fileNameNoExt$'
	Remove

	clearinfo

endfor

selectObject: fileList
Remove

	#Get relevant information from the textgrid (exclude non-labeled segments) and do measurements
