#!/usr/bin/env python2.7

import os
import subprocess
import csv
import pdb

# Combines directory of sample files into one long sample file using sox
# Writes a csv file of initial filename, syllable, note, volume, onset, offset, duration for each individual initial sample

def walk_dir(d):
    '''walks directory given as d, returns list of sample files in directory'''
    os.chdir(d)
    file_lst = []
    for entry in os.listdir(d):
        if len(entry.split('.')) == 6:
            if entry.split('.')[5] == 'wav':
                file_lst.append(entry)
    return file_lst

def write_csv(info_lst):
    '''
    Takes list of lists with information about each individual sample in the file, 6 fields as described in comment at beginning of file
    '''
    with open('outfile.csv','wb') as fh:
        sampwriter = csv.writer(fh, delimiter=',')
        sampwriter.writerow(['syllable','midinote','volume','onset_s','offset_s','duration_s'])
        for entry in info_lst:
            sampwriter.writerow(entry)

def retrieve_soxi_dur(fname):
    prevdir = os.getcwd()
    os.chdir('/Users/jamesanderson-furgeson/tellerstar/supercollider_files/teller_samps/sox_syll/out')
    try:
        out = subprocess.check_output(['soxi', fname], stderr=subprocess.STDOUT).decode('utf-8')
    except subprocess.CalledProcessError as e:
        out = e.output
        #pdb.set_trace()
        #print 'oops'
    os.chdir(prevdir)
    return out.split('\n')[5].split(' ')[10]

def write_info_lst(file_lst):
    '''
    Takes list of files in directory, writes list of lists with 6 fields as described in comment at beginning of file
    '''
    info_lst = []
    curr_point = 0
    for entry in file_lst:
        sub_lst = []
        # initial filename
        sub_lst.append(entry)
        # syllable
        sub_lst.append(entry.split('.')[0])
        # midi note
        sub_lst.append(entry.split('.')[1])
        # volume
        sub_lst.append(entry.split('.')[4])
        # duration from soxi output
        dur = int(retrieve_soxi_dur('/Users/jamesanderson-furgeson/tellerstar/supercollider_files/teller_samps/sox_syll/out/' + entry))
        # onset (curr_point)
        sub_lst.append(str(int(curr_point)))
        # length of sample
        # length = int(round((float(entry.split('.')[2] + '.' + entry.split('.')[3])*48000)))
        # update curr_point to offset of sample
        curr_point += dur
        # offset
        sub_lst.append(str(curr_point))
        # add 0.2 s to current point added between samples by sox
        curr_point += 9600
        # duration
        sub_lst.append(str(dur))
        info_lst.append(sub_lst)
    return info_lst

def sox_combiner(file_lst):
    '''
    Takes file list of audio sample files, runs sox on each audio file to 
    '''
    initcount = 0
    count = 0
    with open('../out2/wavscript', 'wb') as fh:
        fh.write('# concatenate 1st 100 audio files\n')
        fh.write('sox --combine concatenate \\\n')
        for f in file_lst:
            if count == 0 and initcount == 0:
                fh.write('/Users/jamesanderson-furgeson/tellerstar/supercollider_files/teller_samps/sox_syll/out2/output.wav /Users/jamesanderson-furgeson/tellerstar/supercollider_files/teller_samps/sox_syll/out2/silence.wav ' + f + ' /Users/jamesanderson-furgeson/tellerstar/supercollider_files/teller_samps/sox_syll/out2/silence.wav' + ' \\\n')
            elif count <= 100 and initcount != 0:
                fh.write(f + ' /Users/jamesanderson-furgeson/tellerstar/supercollider_files/teller_samps/sox_syll/out2/silence.wav' + ' \\\n')
            elif count > 100 and initcount != 0:
                fh.write('/Users/jamesanderson-furgeson/tellerstar/supercollider_files/teller_samps/sox_syll/out2/output.wav \nsox --combine concatenate \\\n /Users/jamesanderson-furgeson/tellerstar/supercollider_files/teller_samps/sox_syll/out2/output.wav \\\n')
                count = 0
                fh.write(f + ' /Users/jamesanderson-furgeson/tellerstar/supercollider_files/teller_samps/sox_syll/out2/silence.wav' + ' \\\n')
            count += 1
            initcount += 1
    
def sox_normalizer(file_lst):
    '''
    Takes list of audio files in current directory, normalizes using sox unless the sample is sp or br
    '''
    os.chdir('/Users/jamesanderson-furgeson/tellerstar/supercollider_files/teller_samps/sox_syll')
    for f in file_lst:
        if f.split('.')[0] != 'br' and f.split('.')[0] != 'sp':
        #if f.split('.')[0] != 'sp':
            factor = subprocess.check_output(['sox', f, '-n', 'stat', '-v'], stderr=subprocess.STDOUT).decode('utf-8')
            #only normalize to within 90% of max allowable volume to prevent clipping
            factor = str(float(factor)*0.9)
            subprocess.call(['sox', '-v', factor, f, './out/'+f])
        else:
            print "Did not edit file %s" % f

def main():
    file_lst = walk_dir('/Users/jamesanderson-furgeson/tellerstar/supercollider_files/teller_samps/sox_syll/out')
    #sox_normalizer(file_lst)
    #pdb.set_trace()
    info_lst = write_info_lst(file_lst)
    write_csv(info_lst)
    #os.chdir('/Users/jamesanderson-furgeson/tellerstar/supercollider_files/teller_samps/sox_syll/out')
    #sox_combiner(file_lst)
    
if __name__ == '__main__':
    main() 