#!/usr/bin/env python2.7

import os
import copy
import pdb
import textgrid
import shutil

'''
A utility to take a folder with syllable files from the analysis pipeline,
then populate a dictionary of files for use by supercollider.
'''

class sample_file:
    def __init__(self, fname):
        self.fname = fname
        self.fields = [x for x in self.fname.split('.')]
        self.syllable = self.fields[0]
        try:
            self.midi_note = int(self.fields[1])
        except:
            self.midi_note = None
        try:
            self.duration = float(self.fields[2] + '.' + self.fields[3])
        except:
            self.duration = None
        try:
            self.intensity = int(self.fields[4])
        except:
            self.intensity = None
        self.format = self.fields[5]

def walk_dir(d):
    '''walks directory given as d, returns list of sample files in directory'''
    os.chdir(d)
    file_lst = []
    for entry in os.listdir(d):
        if len(entry.split('.')) == 6:
            if entry.split('.')[5] == 'wav':
                file_lst.append(entry)
    return file_lst
    
def write_csv(samples):
    '''Takes list of samples (each entry is instance of sample_file), writes csv (tab separator) of info'''
    with open('samples_info.csv','w') as fh:
        fh.write('syllable\tmidi_note\tduration(s)\tvolume\n')
        for x in samples:
            fh.write(x.syllable + '\t' + str(x.midi_note) + '\t' + str(x.duration) + '\t' + str(x.intensity) + '\n') 

def create_syll_array(txt_grid):
    '''Takes text grid, returns array of syllables in text grid'''
    syll_tier = txt_grid.getFirst('syllable')
    array_str = '['
    for x in syll_tier.intervals:
        try:
            array_str = array_str + '"' + x.mark.decode("utf-8", "ignore") + '"' + ', '
        except:
            print 'something wonky happened with %d --> %d' % (x.minTime, x.maxTime)
    return array_str

def imperative_array():
    with open('/Users/jamesanderson-furgeson/tellerstar/supercollider_files/python_glue/supercollider_array_syll_seq.txt','r') as fh:
        array = []
        for x in fh.read().split(','):
            print x
            if x[0] == '[':
                array.append(x[1:])
            elif x[-1] == ']':
                array.append(x[:-1])
            else:
                array.append(x.split(' ')[1])
    return array

def enumerate_syllables(samples):
    '''
    Takes sample object list, returns list of all syllables occurring
    '''
    return [sample.syllable for sample in samples]

def make_folders(name_lst, location):
    '''
    Takes name_lst of names for folders, directory location, creates folders
    '''
    for name in name_lst:
        if not os.path.exists(location+name):
            os.makedirs(location+name)
            
def transfer_samples(samples, in_dir, out_dir, class_scheme='syllable'):
    '''
    Takes samples list, in_dir, out_dir, classification scheme (class_scheme, defaults to syllable),
    Transfers samples to folders in out_dir that correspond to division by class_scheme
    '''
    for sample in samples:
        if class_scheme == 'syllable':
            shutil.copyfile(in_dir+sample.fname, out_dir+sample.syllable+'/'+sample.fname)

def write_sc_dict(samples):
    '''Takes list of samples, writes text file with info for SuperCollider dictionary of samples'''      

def main():
    in_dir = '/Users/jamesanderson-furgeson/tellerstar/praat/praat3/out2/'
    file_lst = walk_dir(in_dir)
    samples = []
    for fname in file_lst:
        x = sample_file(fname)
        samples.append(copy.copy(x))
    syll_lst = enumerate_syllables(samples)
    out_dir = '/Users/jamesanderson-furgeson/tellerstar/supercollider_files/teller_samps/test/'
    make_folders(syll_lst, out_dir)
    transfer_samples(samples, in_dir, out_dir)
    
    
    
    '''
    write_csv(samples)
    
    txt_grid = textgrid.TextGrid()
    txt_grid.read('/Users/jamesanderson-furgeson/tellerstar/pipeline_execution_16.5.31/concatenated_textgrid/concatenated.TextGrid')
    array_str = create_syll_array(txt_grid)
    with open('out.txt', 'w') as fh:
        fh.write(array_str)
    
    array = imperative_array()
    with open('syll_array.csv','w') as fh:
        for entry in array:
            fh.write(entry + ',')  
    '''
    
if __name__ == '__main__':
    main()