##intensity measurer.praat
##James Anderson-Furgeson

#create list of filenames
clearinfo

form Parameters
    comment Directory that contains the original stimuli
    sentence inDirectory /Users/jamesanderson-furgeson/tellerstar/praat3
    sentence outDirectory /Users/jamesanderson-furgeson/tellerstar/praat3/out
    sentence filetype wav
endform

fileList = Create Strings as file list: "list", inDirectory$ + "/*.wav"

#loop for all files
nFiles = Get number of strings
for d to nFiles
	#read in sound file (wav) 
	selectObject: fileList
	fileName$ = Get string... d
	Read from file: inDirectory$ + "/" + fileName$

	# select name of file without '.wav', assign to fileNameNoExt (find the index of the dot in the soundfilename)...
	dotInd = rindex(fileName$, ".")
	fileNameNoExt$ = left$(fileName$, dotInd - 1)

	#find the corresponding textgrid, and read that textgrid from file
	Read from file: inDirectory$ + "/" + fileNameNoExt$ + ".TextGrid"
	select TextGrid 'fileNameNoExt$'
	#tier 4 is pitch midi value tier
	numberOfIntervals = Get number of intervals: 3

	# set up manipulation
	select Sound 'fileNameNoExt$'
	duration = Get total duration

	manipulation = To Manipulation: 0.01, 75, 600
	select Manipulation 'fileNameNoExt$'

	# create empty pitch tier...
	Create PitchTier: "empty", 0, duration

	# and fill empty pitch tier with points corresponding to pitches in textgrid
	for i to numberOfIntervals
		select TextGrid 'fileNameNoExt$'
		startTime = Get start point: 3, i
		endTime = Get end point: 3, i
		note = Get label of interval: 3, i

		select PitchTier empty
		if (note <> undefined)
			Add point: startTime, note
			Add point: endTime-0.01, note
		endif

	endfor
	
	#select manipulation and pitch tier, replace points in manipulation with pitch tier
	select Manipulation 'fileNameNoExt$'
	plus PitchTier empty
	Replace pitch tier

	select Manipulation 'fileNameNoExt$'
	new_sound = Get resynthesis (overlap-add)
	select Sound 'fileNameNoExt$'
	#Play

	for k to numberOfIntervals
		select TextGrid 'fileNameNoExt$'
	
		label$ = Get label of interval... 1 'k'
		if label$ <> ""
			pitch = Get label of interval... 4 'k'
			volume = Get label of interval... 2 'k'
 			onset = Get starting point... 1 'k'
  			offset = Get end point... 1 'k'
			duration = offset - onset
			select Sound 'fileNameNoExt$'
			Extract part: onset, offset, "rectangular", 1, "no"
			Save as WAV file: outDirectory$ + "/" + label$ + "." + string$ (pitch) + "." + string$ (duration) + "." + string$ (volume) + ".wav"
			Remove
	
		endif
	endfor

	
	# And clean up
	#Remove objects from object menu
	select TextGrid 'fileNameNoExt$'
	Remove
	select Sound 'fileNameNoExt$'
	Remove
	select Sound 'fileNameNoExt$'
	Remove
	select Manipulation 'fileNameNoExt$'
	Remove
	select PitchTier empty
	Remove
	

endfor

selectObject: fileList
Remove